/// <reference types="angular" />
export declare class DropdownService {
    /**
     * Function for determining if an element is completely visible onscreen
     * or if the element is offscreen or only partially visible.  The element
     * must be completely visible for isVisible to return true.
     *
     * @public
     * @param element
     * @returns boolean
     *
     * @memberOf DropdownService
     */
    isVisible(element: HTMLElement): boolean;
    /**
     * Function for controlling the keyboard movements in a list
     *  - TODO: Account for lists with flyout menu(s)
     *  - NOTE: Has not been tested with dropdowns including nested inputs
     *
     * @param options: {
     *  $event: KeyboardEvent,
     *  optionList: ng.IRootElementService,
     *  selectedLocation: number,
     *  selectedOption: any,
     *  toggleButton: ng.IRootElementService,
     *  closeMenu: Function,
     *  taboutFn? : Function
     * }
     */
    listItemKeypress(options: {
        $event: KeyboardEvent;
        optionList: ng.IRootElementService;
        selectedLocation: number;
        selectedOption: any;
        toggleButton: ng.IRootElementService;
        closeMenu: Function;
        taboutFn?: Function;
    }): void;
    /**
     * Function for scrolling the selected item on a list into view
     *
     * @param listContainer
     * @param listItem
     */
    scrollIntoView(listContainer: any, listItem: any): void;
    /**
     * Function for stopping propogation
     *
     * @param $event
     */
    stopEventPropogation($event: any): void;
    /**
     * Function to control the keypress events for the dropdown toggle.
     * When the dropdown is open, tabbing into the dropdown should go to
     * the selectedElement and Enter/Space should trigger the click
     * function which is passed in as toggleOpen
     *
     * @param options: {
     *  $event: KeyboardEvent,
     *  menuOpen: boolean,
     *  selectedElement: HTMLElement,
     *  toggleOpen: Function,
     * }
     */
    toggleKeypress(options: {
        $event: KeyboardEvent;
        menuOpen: boolean;
        selectedElement: HTMLElement;
        toggleOpen: Function;
    }): void;
}
